#
# Login environment variable settings for Oracle
# The code below is done ONLY if the user is "oracle": 
# Set the ULIMITs for the shell and add gcc_old to PATH if it's installed
# 

if [ `id -un` == "oracle" ]; then

  # Get settings, if file(s) exist(s). If not, we simply use defaults.
  if test -f /etc/sysconfig/oracle; then
    # new location as of SL 8.0 is directory /etc/sysconfig/
    . /etc/sysconfig/oracle
  else
    if test -f /etc/rc.config.d/oracle.rc.config; then
      # location is directory /etc/rc.config.d/
      . /etc/rc.config.d/oracle.rc.config
    else
      if test -f /etc/rc.config; then
      # old SuSE location was to have everything in one file
      . /etc/rc.config
      fi
    fi
  fi

  
  ORACLE_SID=mydb

  ORACLE_BASE=/opt/oracle
  ORACLE_HOME=$ORACLE_BASE/product/9ir2

  TNS_ADMIN=$ORACLE_HOME/network/admin
  ORA_NLS33=$ORACLE_HOME/ocommon/nls/admin/data
  PATH=$PATH:$ORACLE_HOME/bin
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH:+$LD_LIBRARY_PATH:}$ORACLE_HOME/lib:$ORACLE_HOME/ctx/lib
  CLASSPATH=$ORACLE_HOME/JRE:$ORACLE_HOME/jlib:$ORACLE_HOME/rdbms/jlib:$ORACLE_HOME/network/jlib

  export ORACLE_BASE ORACLE_HOME ORA_NLS33 ORACLE_SID PATH LD_LIBRARY_PATH CLASSPATH TNS_ADMIN

  # ORACLE_TERM=xterm; export ORACLE_TERM
  # NLS_LANG=AMERICAN_AMERICA.UTF8; export NLS_LANG

  # 
  # This requires the limits to have been increased by root
  # e.g. at boot time by the /etc/rc.d/oracle script, both
  # ulimit and kernel parameters.
  #

  # Add package "gcc_old" gcc 2.95.3 to path - FIRST
  if test -x /opt/gcc295/bin/gcc; then
    export PATH=/opt/gcc295/bin:$PATH
  fi

  # RAC (cluster) component GSD commands don't run when this is
  # set - which it is if a SuSE Java package is installed.
  unset JAVA_BINDIR JAVA_HOME

  # Set ulimits:
  #
  # We suppress any warning messages, so if the hard limits have not been
  # increased by root and the commands don't work we keep silent... 
  # This is because the only one who needs it is the shell that starts
  # the DB server processes, and the number of warning messages created 
  # here is potentially way too much and confusing

  # core dump file size
  ulimit -c ${MAX_CORE_FILE_SIZE_SHELL:-0} 2>/dev/null

  # max number of processes for user
  ulimit -u ${PROCESSES_MAX_SHELL:-16384} 2>/dev/null

  # max number of open files for user
  ulimit -n ${FILE_MAX_SHELL:-65536} 2>/dev/null

  # If /lib/i686 exists, set LD_ASSUME_KERNEL to not use the
  # floating stack version. If you set this without this directory,
  # nothing will work anymore.
  test -d /lib/i686 && export LD_ASSUME_KERNEL=2.2.5
fi

